<TS language="id_ID" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Tentang Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Buat alamat baru</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Baru</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Salin alamat yang dipilih ke clipboard</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Menyalin</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Unjukkan &amp;Kode QR</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Masukan  pesan untuk membuktikan bahwa anda telah mempunyai adress Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Sign &amp; Pesan</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Hapus alamat yang sementara dipilih dari daftar</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Buku Alamat</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Ini adalah alamat Gridcoin Anda untuk menerima pembayaran. Anda dapat memberikan alamat yang berbeda untuk setiap pengirim, sehingga Anda dapat melacak siapa yang membayar Anda.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Hapus</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Salin &amp;Label</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Ubah</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Penulisan data ke file gagal %1</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tidak ada label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog Kata kunci</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Masukkan kata kunci</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Kata kunci baru</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ulangi kata kunci baru</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Hanya untuk staking</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Meng-enkripsikan dompet</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Operasi ini memerlukan kata kunci dompet Anda untuk membuka dompet ini.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Buka dompet</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Ubah kata kunci</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Masukkan kata kunci lama dan baru ke dompet ini.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Menkonfirmasi enkripsi dompet</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Apakah Anda yakin untuk mengenkripsi dompet Anda?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Dompet terenkripsi</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin akan ditutup untuk menyelesaikan proses enkripsi. Ingat bahwa dompet Anda tidak bisa di lindungi dengan enkripsi sepenuhny dari pencurian melalui infeksi malware di komputer Anda.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Enkripsi dompet gagal</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Enkripsi dompet gagal karena kesalahan internal. Dompet Anda tidak dienkripsi.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Kata kunci yang dimasukkan tidak cocok.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Gagal buka dompet</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Kata kunci yang dimasukkan untuk dekripsi dompet tidak cocok.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Passphrase dompet telah berhasil diubah.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Peringatan: tombol Caps Lock aktif!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Gridcoin</source>
        <translation>Gridcoin (CoinHitam)</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Dompet</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Kilasan</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Tampilkan gambaran umum dompet Anda</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Kirim</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Kirim koin ke alamat Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Menerima</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Tampilkan daftar alamat untuk menerima pembayaran</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Lihat riwayat transaksi</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Mengedit daftar alamat-alamat dan label</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>K&amp;eluar</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Keluar dari aplikasi</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Tentang Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Tunjukkan informasi tentang Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Pilihan...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Memodifikasi opsi aturan untuk Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Tampilkan / Sembunyikan</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Enkripsi Dompet...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Ubah Kata Kunci...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Ubah kata kunci yang digunakan untuk enkripsi dompet</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Buka Dompet</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Buka Dompet</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Kunci Dompet</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Kunci dompet</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Pesan &amp;penanda...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifikasi pesan...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Ekspor...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Mengekspor data dari tab saat ini ke dalam file</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Jendela Debug</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Buka konsol debug dan diagnosa</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Berkas</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Pengaturan</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Bantuan</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Klien Gridcoin</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Terbaru</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Menyusul...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transaksi terkirim</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transaksi diterima</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Dompet saat ini &lt;b&gt;terenkripsi&lt;/b&gt; dan &lt;b&gt;terkunci&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Back-up Gagal</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Notifikasi Jaringan</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Kuantitas:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Jumlah:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Biaya:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Dengan Biaya:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Kembalian:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Jumlah</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tanggal</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Konfirmasi</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Terkonfirmasi</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Salin alamat</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Salin label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Salin jumlah</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Salikan jumlah</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Salinkan Biaya</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Salinkan setelah biaya</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Salinkan bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Salinkan output rendah</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Salinkan perubahan</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ya</translation>
    </message>
    <message>
        <source>no</source>
        <translation>tidak</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tidak ada label)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>perubahan dari %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(perubahan)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Ubah Alamat</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Alamat</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Alamat menerima baru</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Alamat mengirim baru</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Ubah alamat menerima</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Ubah alamat mengirim</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Alamat yang dimasukkan "%1" sudah ada di dalam buku alamat.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Tidak dapat membuka dompet.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Pembuatan kunci baru gagal.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>versi</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Penggunaan:</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Utama</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Jaringan</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Petakan port dengan &amp;UPnP</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port proxy (cth. 9050)</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Tampilkan alamat dalam daftar transaksi</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Jendela</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Hanya tampilkan ikon tray setelah meminilisasi jendela</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Meminilisasi ke tray daripada taskbar</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;eminilisasi saat tutup</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Tampilan</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Bahasa Antarmuka Pengguna:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unit untuk menunjukkan nilai:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Pilihan standar unit yang ingin ditampilkan pada layar aplikasi dan saat mengirim koin.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;YA</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Batal</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standar</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Alamat proxy yang diisi tidak valid.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulir</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Tersedia:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Jumlah yang Anda bisa keluarkan sekarang</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Terlalu Muda:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Jumlah:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Jumlah saldo Anda sekarang</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>Request Payment</source>
        <translation>Permintaan Pembayaran</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Pesan:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Jumlah:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Simpan Sebagai...</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Simpan Code QR</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>T/S</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versi Klien</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informasi</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Waktu nyala</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Jumlah hubungan</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Rantai blok</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Jumlah blok terkini</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Waktu blok terakhir</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Buka</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Kosongkan</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsol</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>Kemacetan &amp;Jaringan </translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Masuk:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Keluar:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Berkas catatan debug</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Bersihkan konsol</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Perkiraan blok total</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Tunjukkan</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nama Klien</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Gunakan panah keatas dan kebawah untuk menampilkan sejarah, dan &lt;b&gt;Ctrl-L&lt;/b&gt; untuk bersihkan layar.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Ketik &lt;b&gt;help&lt;/b&gt; untuk menampilkan perintah tersedia.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Kirim Koin</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Masukan...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>Pemilihan otomatis</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Saldo tidak mencukupi!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kuantitas:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Nilai:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Biaya:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Output Rendah:</translation>
    </message>
    <message>
        <source>no</source>
        <translation>tidak</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Dengan Biaya:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Perubahan</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Kirim ke beberapa penerima sekaligus</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Tambahlah &amp;Penerima</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Hapus &amp;Semua</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Konfirmasi aksi pengiriman</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>K&amp;irim</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Salin jumlah</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Konfirmasi pengiriman koin</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Jumlah yang dibayar harus lebih besar dari 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Jumlah melebihi saldo Anda.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Kelebihan total saldo Anda ketika biaya transaksi %1 ditambahkan.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Ditemukan alamat ganda, hanya dapat mengirim ke tiap alamat sekali per operasi pengiriman.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tidak ada label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>J&amp;umlah:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Kirim &amp;Ke:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Pesan:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+J</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Tempel alamat dari salinan</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Masukkan label bagi alamat ini untuk menambahkannya ke buku alamat Anda</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Tanda Tangan / Verifikasi sebuah Pesan</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Tandakan Pesan</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Tempel alamat dari salinan</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Masukan pesan yang ingin ditandai disini</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Salin tanda tangan terpilih ke sistem klipboard</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Tandakan &amp;Pesan</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Hapus semua bidang penanda pesan</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Hapus &amp;Semua</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifikasi Pesan</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Hapus semua bidang verifikasi pesan</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Alamat yang dimasukkan tidak sesuai.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Silahkan periksa alamat dan coba lagi.</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Buka hingga %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/tidak terkonfirmasi</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 konfirmasi</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, belum berhasil disiarkan</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tanggal</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Dari</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>tidak diketahui</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Untuk</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Pesan:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Jumlah</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Rincian transaksi</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Jendela ini menampilkan deskripsi rinci dari transaksi tersebut</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Tanggal</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Jumlah</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Buka hingga %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Terkonfirmasi (%1 konfirmasi)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Terbuat tetapi tidak diterima</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Diterima dengan</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Diterima dari</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Terkirim ke</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pembayaran ke Anda sendiri</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(t/s)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Status transaksi. Arahkan ke bagian ini untuk menampilkan jumlah konfrimasi.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Tanggal dan waktu transaksi tersebut diterima.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Jenis transaksi.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Alamat tujuan dari transaksi.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Jumlah terbuang dari atau ditambahkan ke saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Hari ini</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Minggu ini</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Bulan ini</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Bulan kemarin</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Tahun ini</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Jarak...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>DIterima dengan</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Terkirim ke</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Ke Anda sendiri</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Ditambang</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Lainnya</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Jumlah min</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Salin alamat</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Salin label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Salin jumlah</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Ubah label</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Tampilkan rincian transaksi</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Terkonfirmasi</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tanggal</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Jumlah</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Jarak:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>ke</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Usage:</source>
        <translation>Penggunaan:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Daftar perintah</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Dapatkan bantuan untuk perintah</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Gunakan pilihan %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Anda harus mengatur rpcpassword=&lt;kata sandi&gt; dalam berkas konfigurasi:
%s
Jika berkas tidak ada, buatlah dengan permisi berkas hanya-dapat-dibaca-oleh-pemilik.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Jumlah salah untuk -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Alamat -proxy salah: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Tidak dapat menyelesaikan alamat -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Tidak dapat menyelesaikan alamat -externalip: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Gagal memuat wallet.dat: Dompet rusak</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Gagal memuat wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Memuat alamat...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Tidak dapat mengikat ke %s dengan komputer ini (ikatan gagal %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Eror: Dompet hanya di-buka hanya untuk staking, transaksi gagal dilaksanakan</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Mengirim...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Jumlah salah</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Jaringan tidak diketahui yang ditentukan dalam -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Saldo tidak mencukupi</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Memuat indeks blok...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Memuat dompet...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Tidak dapat menyimpan alamat standar</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Memindai ulang...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Memuat selesai</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gagal</translation>
    </message>
</context>
</TS>